==> igniteui-react-16.16.2.tgz: package/esm2015/lib/Badge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { BadgeVariant_$type } from "./BadgeVariant";
import { BadgeShape_$type } from "./BadgeShape";
/**
 * @hidden
 */
export let Badge = /*@__PURE__*/ (() => {
    class Badge extends BaseElement {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.f = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.f;
        }
        set nativeElement(a) {
            this.f = a;
            this.c.d = this.f;
        }
        get b() {
            let ret_ = this.d.c("variant");
            ret_ = enumGetBox(BadgeVariant_$type, EnumUtil.getEnumValue(BadgeVariant_$type, EnumUtil.parse(BadgeVariant_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(BadgeVariant_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(BadgeVariant_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.d.i("variant", value_);
        }
        get e() {
            let ret_ = this.d.c("outlined");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.d.i("outlined", value_);
        }
        get a() {
            let ret_ = this.d.c("shape");
            ret_ = enumGetBox(BadgeShape_$type, EnumUtil.getEnumValue(BadgeShape_$type, EnumUtil.parse(BadgeShape_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(BadgeShape_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(BadgeShape_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.d.i("shape", value_);
        }
    }
    Badge.$t = /*@__PURE__*/ markType(Badge, 'Badge', BaseElement.$);
    return Badge;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/Badge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { BadgeVariant_$type } from "./BadgeVariant";
import { BadgeShape_$type } from "./BadgeShape";
/**
 * @hidden
 */
export let Badge = /*@__PURE__*/ (() => {
    class Badge extends BaseElement {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.f = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.f;
        }
        set nativeElement(a) {
            this.f = a;
            this.c.o = this.f;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.d.n("variant");
            ret_ = enumGetBox(BadgeVariant_$type, EnumUtil.getEnumValue(BadgeVariant_$type, this.d.f(BadgeVariant_$type, ret_)));
            return EnumUtil.getEnumValue(BadgeVariant_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(BadgeVariant_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.d.v("variant", value_);
        }
        get e() {
            let ret_ = this.d.n("outlined");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.d.v("outlined", value_);
        }
        get a() {
            let ret_ = this.d.n("shape");
            ret_ = enumGetBox(BadgeShape_$type, EnumUtil.getEnumValue(BadgeShape_$type, this.d.f(BadgeShape_$type, ret_)));
            return EnumUtil.getEnumValue(BadgeShape_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(BadgeShape_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.d.v("shape", value_);
        }
    }
    Badge.$t = /*@__PURE__*/ markType(Badge, 'Badge', BaseElement.$);
    return Badge;
})();
